/**
The MIT License (MIT)
Copyright (c) 2017 by Daniel Eichhorn
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:
The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
Please note: I am spending a lot of my free time in developing Software and Hardware
for these projects. Please consider supporting me by
a) Buying my hardware kits from https://blog.squix.org/shop
b) Send a donation: https://www.paypal.me/squix/5USD
c) Or using this affiliate link while shopping: https://www.banggood.com/?p=6R31122484684201508S
See more at https://blog.squix.org
Demo for the buffered graphics library. Renders a 3D cube

Adapted for Paperboy / "Journalismus der Dinge" example by Jakob Vicari
*/

#include <SPI.h>
#include "EPD_WaveShare_29.h"
#include "MiniGrafx.h"
#include "DisplayDriver.h"

#define MINI_BLACK 0
#define MINI_WHITE 1

/*
 Connect the following pins:
 Display  NodeMCU
 BUSY     D1
 RST      D2
 DC       D8
 CS       D3
 CLK      D5
 DIN      D7
 GND      GND
 3.3V     3V3
*/
/*#define CS D3
#define RST D2
#define DC D8
#define BUSY D1*/

#define CS 15  // D8
#define RST 2  // D4
#define DC 5   // D1
#define BUSY 4 // D2

#define BITS_PER_PIXEL 1


uint16_t palette[] = {0, 1};
boolean isFastRefreshEnabled = false;

EPD_WaveShare29 epd(CS, RST, DC, BUSY);
MiniGrafx screenGfx = MiniGrafx(&epd, BITS_PER_PIXEL, palette, EPD_WIDTH, EPD_HEIGHT);
MiniGrafx dialogGfx = MiniGrafx(&epd, BITS_PER_PIXEL, palette, 96, 96);

uint8_t counter = 0;
uint8_t rotation = 0;

void setup() {
  Serial.begin(115200);
  dialogGfx.init();
  screenGfx.init();
  screenGfx.setRotation(1);
  screenGfx.fillBuffer(MINI_WHITE);
  screenGfx.setColor(MINI_BLACK);
  screenGfx.setFont(ArialMT_Plain_10);
  screenGfx.drawString(0, 0, "Willkommen im Journalismus der Dinge!");
  screenGfx.commit();

}



void loop() {

   screenGfx.setRotation(1); // Badge horizontal (0 für vertikal)
   screenGfx.fillBuffer(MINI_WHITE); // mit Weiß füllen
   screenGfx.setColor(MINI_BLACK); // in tiefschwarz schreiben
   screenGfx.setFont(ArialMT_Plain_24);             // große Schrift festlegen
   screenGfx.drawString(50, 30, "Jakob Vicari");             // mittlere Schrift festlegen
   screenGfx.drawString(100, 55, "Buchautor"); // den ersten Wert anpassen, damits zentriert ist
   screenGfx.drawLine(25, 74, screenGfx.getWidth()-25, 74); // Trennlinie ziehen
   screenGfx.setFont(ArialMT_Plain_10);             // kleine Schrift festlegen
   screenGfx.drawString(10, 75, "Lust auf Smalltalk?"); // den ersten Wert anpassen, damits zentriert ist
   screenGfx.drawString(10, 90, "Sprechen Sie mit mir über Journalismus der Dinge, ");
    screenGfx.drawString(10, 105, " smarte Spiegel oder Currywurst!");
   screenGfx.commit(); // Bildschirm aktualisieren
   delay(4000); // 4 Sekunden warten

}
